@@ -226,8 +226,8 @@
 #![doc(test(attr(allow(dead_code))))]
 #![doc(test(attr(allow(unused_variables))))]
 #![warn(missing_docs)]
-#![deny(broken_intra_doc_links)]
-#![deny(invalid_codeblock_attributes)]
+#![deny(rustdoc::broken_intra_doc_links)]
+#![deny(rustdoc::invalid_codeblock_attributes)]
 
 #[cfg(feature = "native-test-stubs")]
 mod native_test_stubs;
